
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.features.persistence.persistence import PersistenceUI

web.site_root = PersistenceUI
